@@ -279,21 +279,6 @@ void CalendarBasePrivate::handleUidChange(const Akonadi::Item &oldItem, const Ak
 
     const QString newUid = newIncidence->uid();
     if (mItemIdByUid.contains(newIdentifier)) {
-        Incidence::Ptr oldIncidence = CalendarUtils::incidence(oldItem);
-#if 0
-        qCWarning(AKONADICALENDAR_LOG) << "New uid shouldn't be known: "  << newIdentifier << "; id="
-                                       << newItem.id() << "; oldItem.id=" << mItemIdByUid[newIdentifier]
-                                       << "; new summary= " << newIncidence->summary()
-                                       << "; new recurrenceId=" << newIncidence->recurrenceId()
-                                       << "; oldIncidence" << oldIncidence;
-#endif
-        if (oldIncidence) {
-#if 0
-            qCWarning(AKONADICALENDAR_LOG) << "; oldIncidence uid=" << oldIncidence->uid()
-                                           << "; oldIncidence recurrenceId = " << oldIncidence->recurrenceId()
-                                           << "; oldIncidence summary = " << oldIncidence->summary();
-#endif
-        }
         Q_ASSERT(false);
         return;
     }
@@ -311,15 +296,6 @@ void CalendarBasePrivate::handleUidChange(const Akonadi::Item &oldItem, const Ak
     }
 
     if (newIncidence->instanceIdentifier() == oldIncidence->instanceIdentifier()) {
-#if 0
-        qCWarning(AKONADICALENDAR_LOG) << "New uid=" << newIncidence->uid() << "; old uid=" << oldIncidence->uid()
-                                       << "; new recurrenceId="
-                                       << newIncidence->recurrenceId()
-                                       << "; old recurrenceId=" << oldIncidence->recurrenceId()
-                                       << "; new summary = " << newIncidence->summary()
-                                       << "; old summary = " << oldIncidence->summary()
-                                       << "; id = " << newItem.id();
-#endif
         Q_ASSERT(false); // The reason we're here in the first place
         return;
     }
@@ -398,8 +374,6 @@ Akonadi::Item CalendarBase::item(Akonadi::Item::Id id) const
     auto it = d->mItemById.constFind(id);
     if (it != d->mItemById.cend()) {
         i = *it;
-    } else {
-        qCDebug(AKONADICALENDAR_LOG) << "Can't find any item with id " << id;
     }
     return i;
 }
