@@ -35,15 +35,11 @@ namespace KIdentityManagementCore
 class Identity;
 }
 
-namespace Kleo
-{
-class KeyResolver;
-}
-
 namespace MessageComposer
 {
-class Composer;
+class ComposerJob;
 class ContactPreference;
+class KeyResolver;
 }
 
 namespace MailTransport
@@ -173,13 +169,13 @@ protected:
     virtual bool showKeyApprovalDialog() const;
 
 private:
-    std::vector<std::unique_ptr<MessageComposer::Composer>>
+    std::vector<std::unique_ptr<MessageComposer::ComposerJob>>
     buildComposers(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagementCore::Identity &identity, const MessageData &msg);
 
-    void populateComposer(MessageComposer::Composer *composer, const MessageData &msg);
+    void populateComposer(MessageComposer::ComposerJob *composerJob, const MessageData &msg);
 
     bool determineWhetherToSign(bool doSignCompletely,
-                                Kleo::KeyResolver *keyResolver,
+                                MessageComposer::KeyResolver *keyResolver,
                                 ITIPHandlerDialogDelegate *dialogDelegate,
                                 const KIdentityManagementCore::Identity &identity,
                                 bool signSomething,
@@ -188,7 +184,7 @@ private:
                                 bool &canceled);
 
     bool determineWhetherToEncrypt(bool doEncryptCompletely,
-                                   Kleo::KeyResolver *keyResolver,
+                                   MessageComposer::KeyResolver *keyResolver,
                                    ITIPHandlerDialogDelegate *dialogDelegate,
                                    const KIdentityManagementCore::Identity &identity,
                                    bool encryptSomething,
@@ -201,13 +197,13 @@ private:
     addKeysToContext(const QString &gnupgHome, const QList<QPair<QStringList, std::vector<GpgME::Key>>> &data, const std::map<QByteArray, QString> &autocrypt);
 
     void queueMessage(const MailTransport::Transport *transport,
-                      const MessageComposer::Composer *composer,
+                      const MessageComposer::ComposerJob *composerJob,
                       const KCalendarCore::IncidenceBase::Ptr &incidence,
                       const KIdentityManagementCore::Identity &identity,
                       const MessageData &msg,
                       const KMime::Message::Ptr &message);
 
-    void populateKeyResolverContactsPreferences(Kleo::KeyResolver &keyResolver, const QStringList &addresses);
+    void populateKeyResolverContactsPreferences(MessageComposer::KeyResolver &keyResolver, const QStringList &addresses);
 };
 }
 
