@@ -32,7 +32,7 @@ void TodoPurgerPrivate::onCalendarLoaded(bool success, const QString &message)
     }
 }
 
-void TodoPurgerPrivate::onItemsDeleted(int changeId, const QVector<Item::Id> &deletedItems, IncidenceChanger::ResultCode result, const QString &message)
+void TodoPurgerPrivate::onItemsDeleted(int changeId, const QList<Item::Id> &deletedItems, IncidenceChanger::ResultCode result, const QString &message)
 {
     if (changeId != m_currentChangeId) {
         return; // Not ours.
@@ -161,3 +161,7 @@ QString TodoPurger::lastError() const
 {
     return d->m_lastError;
 }
+
+#include "moc_todopurger_p.cpp"
+
+#include "moc_todopurger.cpp"
